CommonProperties

Struct CommonProperties 

pub struct CommonProperties {
Show 15 fields pub type: String, pub id: String, pub spec_version: Option<String>, pub created: DateTime<Utc>, pub modified: DateTime<Utc>, pub created_by_ref: Option<String>, pub revoked: Option<bool>, pub labels: Option<Vec<String>>, pub confidence: Option<u8>, pub lang: Option<String>, pub external_references: Option<Vec<ExternalReference>>, pub object_marking_refs: Option<Vec<String>>, pub granular_markings: Option<Vec<GranularMarking>>, pub extensions: Option<HashMap<String, Value>>, pub custom_properties: HashMap<String, Value>,
}
Common STIX properties shared by STIX domain objects

Fields

type: Stringid: Stringspec_version: Option<String>created: DateTime<Utc>modified: DateTime<Utc>created_by_ref: Option<String>revoked: Option<bool>labels: Option<Vec<String>>confidence: Option<u8>lang: Option<String>external_references: Option<Vec<ExternalReference>>object_marking_refs: Option<Vec<String>>granular_markings: Option<Vec<GranularMarking>>extensions: Option<HashMap<String, Value>>custom_properties: HashMap<String, Value>

Implementations

Source

impl CommonProperties

pub fn new( object_type: impl Into<String>, created_by_ref: Option<String>, ) -> Self

pub fn new_version(&mut self)

Creates a new version of this object by updating the modified timestamp

In STIX, when you update an object, you keep the same ID and created timestamp but update the modified timestamp to indicate a new version.

Examples
use stix_rs::Malware;
use chrono::Utc;

let mut malware = Malware::builder()
    .name("BadWare")
    .malware_types(vec!["trojan".into()])
    .build()
    .unwrap();

let original_modified = malware.common.modified;
std::thread::sleep(std::time::Duration::from_millis(10));

malware.common.new_version();
assert!(malware.common.modified > original_modified);